# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.

from __future__ import unicode_literals
from __future__ import print_function

from commondata.utils import Place, PlaceGenerator


class PlaceInBelgium(Place):
    def __unicode__(self):
        return self.fr

class Country(PlaceInBelgium):
    value = 0

class Region(PlaceInBelgium):
    value = 1

class Province(PlaceInBelgium):
    value = 2

class City(PlaceInBelgium):
    value = 3

class Village(City):
    value = 4

class Township(City):  # "Section" d'une commune,  "Stadtteil"
    value = 4


def root():

    pg = PlaceGenerator()
    pg.install(Country, Region, Province, City, Village, Township)
    pg.set_args('fr nl de en')

    belgium = pg.country("Belgique", "België", "Belgien", "Belgium")

    pg.region("Bruxelles", "Brussel", "Brüssel", "Brussels")
    from .brussels import populate ; populate(pg)
    
    pg.set_args('fr nl de en')
    pg.region(
        "Région flamande", "Vlaams Gewest", "Flandern", "Flemish Region")
    from .antwerpen import populate ; populate(pg)
    from .luxembourg import populate ; populate(pg)
    from .oostvlaanderen import populate ; populate(pg)
    from .westvlaanderen import populate ; populate(pg)
    from .vlaamsbrabant import populate ; populate(pg)

    pg.set_args('fr nl de en')
    pg.region(
        "Région wallonne", "Wallonië", "Wallonische Region", "Wallonia")
    from .namur import populate ; populate(pg)
    from .liege import populate ; populate(pg)
    from .hainaut import populate ; populate(pg)
    from .limburg import populate ; populate(pg)
    from .brabantwallon import populate ; populate(pg)
    
    return belgium



# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(pg):

    pg.set_args('fr nl de en')
    pg.province("Limbourg", "Limburg", "Limburg", "Limbourg")
    pg.set_args('zip_code fr nl de en')
    
    pg.village("3800", "Aalst-bij-Sint-Truiden", "", "", "")



# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(pg):

    pg.set_args('fr nl de en')
    pg.province("Brabant wallon", "Waals-Brabant", "Wallonisch-Brabant", "Brabant wallon")
    pg.set_args('zip_code fr nl de en')

    pg.city("1300", "Wavre", "Waver")
    pg.township("1300", "Limal", wa="Nimal")

    pg.township("1301", "Bierges", "", "", "")
    pg.city("1310", "La Hulpe", "Terhulpen", "La Hulpe", "La Hulpe")
    pg.city("1315", "Glimes", "", "", "")
    pg.city("1315", "Incourt", "", "", "")
    pg.city("1315", "Opprebais", "", "", "")
    pg.city("1315", "Piètrebais", "", "", "")
    pg.city("1315", "Roux-Miroir", "", "", "")
    pg.city("1320", "Beauvechain", "", "", "")
    pg.city("1320", "Hamme-Mille", "", "", "")
    pg.city("1320", "L'Ecluse", "", "", "")
    pg.city("1320", "Nodebais", "", "", "")
    pg.city("1320", "Tourinnes-la-Grosse", "", "", "")
    pg.city("1325", "Bonlez", "", "", "")
    pg.city("1325", "Chaumont-Gistoux", "", "", "")
    pg.city("1325", "Corroy-le-Grand", "", "", "")
    pg.city("1325", "Dion-Valmont", "", "", "")
    pg.city("1325", "Longueville", "", "", "")
    pg.city("1330", "Rixensart", "", "", "")
    pg.city("1331", "Rosières", "", "", "")
    pg.city("1332", "Genval", "", "", "")
    pg.city("1340", "Ottignies", "", "", "")
    pg.city("1341", "Céroux-Mousty", "", "", "")
    pg.city("1342", "Limelette", "", "", "")
    pg.city("1348", "Louvain-la-Neuve", "Louvain-la-Neuve", "Neu-Löwen")
    pg.city("1350", "Enines", "", "", "")
    pg.city("1350", "Folx-les-Caves", "", "", "")
    pg.city("1350", "Jandrain-Jandrenouille", "", "", "")
    pg.city("1350", "Jauche", "", "", "")
    pg.city("1350", "Marilles", "", "", "")
    pg.city("1350", "Noduwez", "", "", "")
    pg.city("1350", "Orp-Jauche", "", "", "")
    pg.city("1350", "Orp-le-Grand", "", "", "")
    pg.city("1357", "Hélécine", "", "", "")
    pg.city("1357", "Linsmeau", "", "", "")
    pg.city("1357", "Neerheylissem", "", "", "")
    pg.city("1357", "Opheylissem", "", "", "")
    pg.city("1360", "Malèves-Ste-Marie-Wastines", "", "", "")
    pg.city("1360", "Orbais", "", "", "")
    pg.city("1360", "Thorembais-les-Béguines", "", "", "")
    pg.city("1360", "Thorembais-Saint-Trond", "", "", "")
    pg.city("1360", "Perwez", "Perwijs", "Perwez", "Perwez")
    pg.city("1367", "Autre-Eglise", "", "", "")
    pg.city("1367", "Bomal (Bt.)", "", "", "")
    pg.city("1367", "Geest-Gérompont-Pt-Rosière", "", "", "")
    pg.city("1367", "Gérompont", "", "", "")
    pg.city("1367", "Grand-Rosière-Hottomont", "", "", "")
    pg.city("1367", "Huppaye", "", "", "")
    pg.city("1367", "Mont-Saint-André", "", "", "")
    pg.city("1367", "Ramillies", "", "", "")
    pg.city("1370", "Dongelberg", "", "", "")
    pg.city("1370", "Jauchelette", "", "", "")
    pg.city("1370", "Jodoigne", "", "", "")
    pg.city("1370", "Jodoigne-Souveraine", "", "", "")
    pg.city("1370", "Lathuy", "", "", "")
    pg.city("1370", "Mélin", "", "", "")
    pg.city("1370", "Piétrain", "", "", "")
    pg.city("1370", "Saint-Jean-Geest", "", "", "")
    pg.city("1370", "Saint-Remy-Geest", "", "", "")
    pg.city("1370", "Zétrud-Lumay", "", "", "")
    pg.city("1380", "Couture-Saint-Germain", "", "", "")
    pg.city("1380", "Lasne", "", "", "")
    pg.city("1380", "Lasne-Chapelle-St-Lambert", "", "", "")
    pg.city("1380", "Maransart", "", "", "")
    pg.city("1380", "Ohain", "", "", "")
    pg.city("1380", "Plancenoit", "", "", "")
    pg.city("1390", "Archennes", "", "", "")
    pg.city("1390", "Biez", "", "", "")
    pg.city("1390", "Bossut-Gottechain", "", "", "")
    pg.city("1390", "Grez-Doiceau", "", "", "")
    pg.city("1390", "Nethen", "", "", "")
    pg.city("1400", "Monstreux", "", "", "")
    pg.city("1400", "Nivelles", "Nijvel", "Nivelles", "Nivelles")
    pg.city("1401", "Baulers", "", "", "")
    pg.city("1402", "Thines", "", "", "")
    pg.city("1404", "Bornival", "", "", "")

    pg.city("1410", "Waterloo", "", "", "")
    pg.city("1420", "Braine-l'Alleud", "", "", "")
    pg.city("1421", "Ophain-Bois-Seigneur-Isaac", "", "", "")
    pg.city("1428", "Lillois-Witterzée", "", "", "")
    pg.city("1430", "Bierghes", "", "", "")
    pg.city("1430", "Quenast", "", "", "")
    pg.city("1430", "Rebecq", "", "", "")
    pg.city("1430", "Rebecq-Rognon", "", "", "")
    pg.city("1435", "Corbais", "", "", "")
    pg.city("1435", "Hévillers", "", "", "")
    pg.city("1435", "Mont-Saint-Guibert", "", "", "")
    pg.city("1440", "Braine-le-Château", "", "", "")
    pg.city("1440", "Wauthier-Braine", "", "", "")
    pg.city("1450", "Chastre", "", "", "")
    pg.city("1450", "Chastre-Villeroux-Blanmont", "", "", "")
    pg.city("1450", "Cortil-Noirmont", "", "", "")
    pg.city("1450", "Gentinnes", "", "", "")
    pg.city("1450", "Saint-Géry", "", "", "")
    pg.city("1457", "Nil-St-Vincent-St-Martin", "", "", "")
    pg.city("1457", "Tourinnes-Saint-Lambert", "", "", "")
    pg.city("1457", "Walhain", "", "", "")
    pg.city("1457", "Walhain-Saint-Paul", "", "", "")
    pg.city("1460", "Ittre", "", "", "")
    pg.city("1460", "Virginal-Samme", "", "", "")
    pg.city("1461", "Haut-Ittre", "", "", "")
    pg.city("1470", "Baisy-thy", "", "", "")
    pg.city("1470", "Bousval", "", "", "")
    pg.city("1470", "Genepiën", "Genappe", "Genappe", "Genappe")
    pg.city("1471", "Loupoigne", "", "", "")
    pg.city("1472", "Vieux-Genappe", "", "", "")
    pg.city("1473", "Glabais", "", "", "")
    pg.city("1474", "Ways", "", "", "")
    pg.city("1476", "Houtain-le-Val", "", "", "")
    pg.city("1480", "Clabecq", "", "", "")
    pg.city("1480", "Oisquercq", "", "", "")
    pg.city("1480", "Saintes", "", "", "")
    pg.city("1480", "Tubize", "", "", "")
    pg.city("1490", "Court-Saint-Etienne", "", "", "")
    pg.city("1495", "Marbais (Bt.)", "", "", "")
    pg.city("1495", "Mellery", "", "", "")
    pg.city("1495", "Sart-Dames-Avelines", "", "", "")
    pg.city("1495", "Tilly", "", "", "")
    pg.city("1495", "Villers-la-Ville", "", "", "")
